@@ -41,6 +41,7 @@ class Dialog(BaseWidget):
         """
         BaseWidget._setup(self, parent, {})
         self._winsys = self.master.tk.call("tk", "windowingsystem")
+        self._parent = parent
         self._toplevel = None
         self._title = title or " "
         self._result = None
@@ -49,40 +50,35 @@ class Dialog(BaseWidget):
 
     def _locate(self):
         toplevel = self._toplevel
-        master = toplevel.master
-        screen_height = toplevel.winfo_screenheight()
-        screen_width = toplevel.winfo_screenwidth()
-
-        toplevel.update_idletasks()
-        if master.winfo_viewable():
-            m_width = master.winfo_width()
-            m_height = master.winfo_height()
-            m_x = master.winfo_rootx()
-            m_y = master.winfo_rooty()
+        if self._parent is None:
+            master = toplevel.master
         else:
-            m_width = screen_width
-            m_height = screen_height
-            m_x = m_y = 0
-        w_width = toplevel.winfo_reqwidth()
-        w_height = toplevel.winfo_reqheight()
-        x = int(m_x + (m_width - w_width) * 0.45)
-        y = int(m_y + (m_height - w_height) * 0.3)
-        if x + w_width > screen_width:
-            x = screen_width - w_width
-        elif x < 0:
-            x = 0
-        if y + w_height > screen_height:
-            y = screen_height - w_height
-        elif y < 0:
-            y = 0
+            master = self._parent
+        x = master.winfo_rootx()
+        y = master.winfo_rooty()
         toplevel.geometry(f"+{x}+{y}")
 
-    def show(self):
-        """Show the popup dialog"""
+    def show(self, position=None):
+        """Show the popup dialog
+        Parameters:
 
+            position: Tuple[int, int]
+                The x and y coordinates used to position the dialog. By
+                default the dialog will anchor at the NW corner of the
+                parent window.
+        """
         self._result = None
         self.build()
-        self._locate()
+
+        if position is None:
+            self._locate()
+        else:
+            try:
+                x, y = position
+                self._toplevel.geometry(f'+{x}+{y}')
+            except:
+                self._locate()
+
         self._toplevel.deiconify()
         if self._alert:
             self._toplevel.bell()
@@ -148,7 +144,7 @@ class Dialog(BaseWidget):
         self._toplevel.bind("<Escape>", lambda _: self._toplevel.destroy())
 
         # set position of popup from parent window
-        #self._locate()
+        # self._locate()
 
         # create widgets
         self.create_body(self._toplevel)
@@ -187,7 +183,7 @@ class MessageDialog(Dialog):
         default=None,
         padding=(20, 20),
         icon=None,
-        **kwargs
+        **kwargs,
     ):
         """
         Parameters:
@@ -263,12 +259,12 @@ class MessageDialog(Dialog):
         self._default = (default,)
         self._padding = padding
         self._icon = icon
-        self._localize = kwargs.get('localize')
+        self._localize = kwargs.get("localize")
 
         if buttons is None:
             self._buttons = [
                 f"{MessageCatalog.translate('Cancel')}:secondary",
-                f"{MessageCatalog.translate('OK')}:primary"
+                f"{MessageCatalog.translate('OK')}:primary",
             ]
         else:
             self._buttons = buttons
@@ -290,7 +286,7 @@ class MessageDialog(Dialog):
                     icon_lbl.pack(side=LEFT, padx=5)
                 except:
                     # icon is neither data nor a valid file path
-                    print('MessageDialog icon is invalid')
+                    print("MessageDialog icon is invalid")
 
         if self._message:
             for msg in self._message.split("\n"):
@@ -346,9 +342,9 @@ class MessageDialog(Dialog):
             command()
         self._toplevel.destroy()
 
-    def show(self):
+    def show(self, position=None):
         """Create and display the popup messagebox."""
-        super().show()
+        super().show(position)
 
 
 class QueryDialog(Dialog):
@@ -496,30 +492,33 @@ class QueryDialog(Dialog):
         try:
             self._result = self._datatype(self._result)
         except ValueError:
-            msg = MessageCatalog.translate('Should be of data type')
+            msg = MessageCatalog.translate("Should be of data type")
             Messagebox.ok(
                 message=f"{msg} `{self._datatype}`",
                 title=MessageCatalog.translate("Invalid data type"),
+                parent=self._toplevel
             )
             return False
 
         # max value range
         if self._maxvalue is not None:
             if self._result > self._maxvalue:
-                msg = MessageCatalog.translate('Number cannot be greater than')
+                msg = MessageCatalog.translate("Number cannot be greater than")
                 Messagebox.ok(
                     message=f"{msg} {self._maxvalue}",
                     title=MessageCatalog.translate("Out of range"),
+                    parent=self._toplevel
                 )
                 return False
 
         # min value range
         if self._minvalue is not None:
             if self._result < self._minvalue:
-                msg = MessageCatalog.translate('Number cannot be less than')
+                msg = MessageCatalog.translate("Number cannot be less than")
                 Messagebox.ok(
                     message=f"{msg} {self._minvalue}",
                     title=MessageCatalog.translate("Out of range"),
+                    parent=self._toplevel
                 )
                 return False
 
@@ -564,8 +563,9 @@ class DatePickerDialog:
     ![](../../assets/dialogs/date-picker-dialog.png)
 
     """
-    
-    locale.setlocale(locale.LC_ALL, locale.setlocale(locale.LC_TIME,''))
+
+    locale.setlocale(locale.LC_ALL, locale.setlocale(locale.LC_TIME, ""))
+
     def __init__(
         self,
         parent=None,
@@ -605,7 +605,7 @@ class DatePickerDialog:
             resizable=(False, False),
             topmost=True,
             minsize=(226, 1),
-            iconify=True
+            iconify=True,
         )
         self.firstweekday = firstweekday
         self.startdate = startdate or datetime.today().date()
@@ -635,7 +635,7 @@ class DatePickerDialog:
         self.frm_header.pack(fill=X)
 
         # setup the toplevel widget
-        self.root.withdraw() # reset the iconify state
+        self.root.withdraw()  # reset the iconify state
         self.frm_calendar.update_idletasks()  # actualize geometry
 
         # create visual components
@@ -768,13 +768,15 @@ class DatePickerDialog:
             List[str]:
                 A list of weekday column names for the calendar header.
         """
-        weekdays = [MessageCatalog.translate("Mo"), 
-                    MessageCatalog.translate("Tu"),
-                    MessageCatalog.translate("We"), 
-                    MessageCatalog.translate("Th"), 
-                    MessageCatalog.translate("Fr"), 
-                    MessageCatalog.translate("Sa"), 
-                    MessageCatalog.translate("Su")]
+        weekdays = [
+            MessageCatalog.translate("Mo"),
+            MessageCatalog.translate("Tu"),
+            MessageCatalog.translate("We"),
+            MessageCatalog.translate("Th"),
+            MessageCatalog.translate("Fr"),
+            MessageCatalog.translate("Sa"),
+            MessageCatalog.translate("Su"),
+        ]
         header = weekdays[self.firstweekday :] + weekdays[: self.firstweekday]
         return header
 
@@ -844,32 +846,31 @@ class DatePickerDialog:
 
     def _set_window_position(self):
         """Move the window the to bottom-right of the parent widget, or
-        to the middle of the screen if no parent is provided.
+        the top-left corner of the master window if no parent is 
+        provided.
         """
-        width = self.root.winfo_reqwidth()
-        height = self.root.winfo_reqheight()
         if self.parent:
             xpos = self.parent.winfo_rootx() + self.parent.winfo_width()
             ypos = self.parent.winfo_rooty() + self.parent.winfo_height()
             self.root.geometry(f"+{xpos}+{ypos}")
         else:
-            xpos = self.root.winfo_screenwidth() // 2 - width
-            ypos = self.root.winfo_screenheight() // 2 - height
+            xpos = self.root.master.winfo_rootx()
+            ypos = self.root.master.winfo_rooty()
             self.root.geometry(f"+{xpos}+{ypos}")
 
     @staticmethod
     def _nextmonth(year, month):
         if month == 12:
-            return year+1, 1
+            return year + 1, 1
         else:
-            return year, month+1
+            return year, month + 1
 
     @staticmethod
     def _prevmonth(year, month):
         if month == 1:
-            return year-1, 12
+            return year - 1, 12
         else:
-            return year, month-1            
+            return year, month - 1
 
 
 class FontDialog(Dialog):
@@ -952,7 +953,11 @@ class FontDialog(Dialog):
         container = ttk.Frame(master)
         container.pack(fill=BOTH, expand=YES, side=LEFT)
 
-        header = ttk.Label(container, text=MessageCatalog.translate("Family"), font="TkHeadingFont")
+        header = ttk.Label(
+            container,
+            text=MessageCatalog.translate("Family"),
+            font="TkHeadingFont",
+        )
         header.pack(fill=X, pady=(0, 2), anchor=N)
 
         listbox = ttk.Treeview(
@@ -989,7 +994,11 @@ class FontDialog(Dialog):
         container = ttk.Frame(master)
         container.pack(side=LEFT, fill=Y, padx=(10, 0))
 
-        header = ttk.Label(container, text=MessageCatalog.translate("Size"), font="TkHeadingFont")
+        header = ttk.Label(
+            container,
+            text=MessageCatalog.translate("Size"),
+            font="TkHeadingFont",
+        )
         header.pack(fill=X, pady=(0, 2), anchor=N)
 
         sizes_listbox = ttk.Treeview(container, height=7, columns=[0], show="")
@@ -1020,7 +1029,9 @@ class FontDialog(Dialog):
         container = ttk.Frame(master, padding=padding)
         container.pack(fill=X, padx=2, pady=2, anchor=N)
 
-        weight_lframe = ttk.Labelframe(container, text=MessageCatalog.translate("Weight"), padding=5)
+        weight_lframe = ttk.Labelframe(
+            container, text=MessageCatalog.translate("Weight"), padding=5
+        )
         weight_lframe.pack(side=LEFT, fill=X, expand=YES)
         opt_normal = ttk.Radiobutton(
             master=weight_lframe,
@@ -1038,7 +1049,9 @@ class FontDialog(Dialog):
         )
         opt_bold.pack(side=LEFT, padx=5, pady=5)
 
-        slant_lframe = ttk.Labelframe(container, text=MessageCatalog.translate("Slant"), padding=5)
+        slant_lframe = ttk.Labelframe(
+            container, text=MessageCatalog.translate("Slant"), padding=5
+        )
         slant_lframe.pack(side=LEFT, fill=X, padx=10, expand=YES)
         opt_roman = ttk.Radiobutton(
             master=slant_lframe,
@@ -1056,14 +1069,20 @@ class FontDialog(Dialog):
         )
         opt_italic.pack(side=LEFT, padx=5, pady=5)
 
-        effects_lframe = ttk.Labelframe(container, text=MessageCatalog.translate("Effects"), padding=5)
+        effects_lframe = ttk.Labelframe(
+            container, text=MessageCatalog.translate("Effects"), padding=5
+        )
         effects_lframe.pack(side=LEFT, padx=(2, 0), fill=X, expand=YES)
         opt_underline = ttk.Checkbutton(
-            master=effects_lframe, text=MessageCatalog.translate("underline"), variable=self._underline
+            master=effects_lframe,
+            text=MessageCatalog.translate("underline"),
+            variable=self._underline,
         )
         opt_underline.pack(side=LEFT, padx=5, pady=5)
         opt_overstrike = ttk.Checkbutton(
-            master=effects_lframe, text=MessageCatalog.translate("overstrike"), variable=self._overstrike
+            master=effects_lframe,
+            text=MessageCatalog.translate("overstrike"),
+            variable=self._overstrike,
         )
         opt_overstrike.pack(side=LEFT, padx=5, pady=5)
 
@@ -1071,10 +1090,16 @@ class FontDialog(Dialog):
         container = ttk.Frame(master, padding=padding)
         container.pack(fill=BOTH, expand=YES, anchor=N)
 
-        header = ttk.Label(container, text=MessageCatalog.translate("Preview"), font="TkHeadingFont")
+        header = ttk.Label(
+            container,
+            text=MessageCatalog.translate("Preview"),
+            font="TkHeadingFont",
+        )
         header.pack(fill=X, pady=2, anchor=N)
 
-        content = MessageCatalog.translate("The quick brown fox jumps over the lazy dog.")
+        content = MessageCatalog.translate(
+            "The quick brown fox jumps over the lazy dog."
+        )
         self._preview_text = ttk.Text(
             master=container,
             height=3,
@@ -1154,15 +1179,19 @@ class Messagebox:
             **kwargs (Dict):
                 Other optional keyword arguments.
         """
-        sd = MessageDialog(
+        dialog = MessageDialog(
             message=message,
             title=title,
             parent=parent,
             buttons=["OK:primary"],
             icon=Icon.info,
-            localize=True
+            localize=True,
         )
-        sd.show()
+        if "position" in kwargs:
+            position = kwargs.pop("position")
+        else:
+            position = None
+        dialog.show(position)
 
     @staticmethod
     def show_warning(message, title=" ", parent=None, **kwargs):
@@ -1188,7 +1217,7 @@ class Messagebox:
             **kwargs (Dict):
                 Other optional keyword arguments.
         """
-        sd = MessageDialog(
+        dialog = MessageDialog(
             message=message,
             title=title,
             parent=parent,
@@ -1198,7 +1227,11 @@ class Messagebox:
             localize=True,
             **kwargs,
         )
-        sd.show()
+        if "position" in kwargs:
+            position = kwargs.pop("position")
+        else:
+            position = None
+        dialog.show(position)
 
     @staticmethod
     def show_error(message, title=" ", parent=None, **kwargs):
@@ -1224,7 +1257,7 @@ class Messagebox:
             **kwargs (Dict):
                 Other optional keyword arguments.
         """
-        sd = MessageDialog(
+        dialog = MessageDialog(
             message=message,
             title=title,
             parent=parent,
@@ -1234,7 +1267,11 @@ class Messagebox:
             localize=True,
             **kwargs,
         )
-        sd.show()
+        if "position" in kwargs:
+            position = kwargs.pop("position")
+        else:
+            position = None
+        dialog.show(position)
 
     @staticmethod
     def show_question(
@@ -1283,7 +1320,7 @@ class Messagebox:
                 The symbolic name of the button pressed, or None if the
                 window is closed without pressing a button.
         """
-        sd = MessageDialog(
+        dialog = MessageDialog(
             message=message,
             title=title,
             parent=parent,
@@ -1293,8 +1330,12 @@ class Messagebox:
             localize=True,
             **kwargs,
         )
-        sd.show()
-        return sd.result
+        if "position" in kwargs:
+            position = kwargs.pop("position")
+        else:
+            position = None
+        dialog.show(position)
+        return dialog.result
 
     @staticmethod
     def ok(message, title=" ", alert=False, parent=None, **kwargs):
@@ -1323,7 +1364,7 @@ class Messagebox:
             **kwargs (Dict):
                 Other optional keyword arguments.
         """
-        sd = MessageDialog(
+        dialog = MessageDialog(
             title=title,
             message=message,
             parent=parent,
@@ -1332,7 +1373,11 @@ class Messagebox:
             localize=True,
             **kwargs,
         )
-        sd.show()
+        if "position" in kwargs:
+            position = kwargs.pop("position")
+        else:
+            position = None
+        dialog.show(position)
 
     @staticmethod
     def okcancel(message, title=" ", alert=False, parent=None, **kwargs):
@@ -1367,11 +1412,20 @@ class Messagebox:
                 The symbolic name of the button pressed, or None if the
                 window is closed without pressing a button.
         """
-        sd = MessageDialog(
-            title=title, message=message, parent=parent, alert=alert, localize=True, **kwargs
+        dialog = MessageDialog(
+            title=title,
+            message=message,
+            parent=parent,
+            alert=alert,
+            localize=True,
+            **kwargs,
         )
-        sd.show()
-        return sd.result
+        if "position" in kwargs:
+            position = kwargs.pop("position")
+        else:
+            position = None
+        dialog.show(position)
+        return dialog.result
 
     @staticmethod
     def yesno(message, title=" ", alert=False, parent=None, **kwargs):
@@ -1406,7 +1460,7 @@ class Messagebox:
                 The symbolic name of the button pressed, or None if the
                 window is closed without pressing a button.
         """
-        sd = MessageDialog(
+        dialog = MessageDialog(
             title=title,
             message=message,
             parent=parent,
@@ -1415,8 +1469,12 @@ class Messagebox:
             localize=True,
             **kwargs,
         )
-        sd.show()
-        return sd.result
+        if "position" in kwargs:
+            position = kwargs.pop("position")
+        else:
+            position = None
+        dialog.show(position)
+        return dialog.result
 
     @staticmethod
     def yesnocancel(message, title=" ", alert=False, parent=None, **kwargs):
@@ -1451,7 +1509,7 @@ class Messagebox:
                 The symbolic name of the button pressed, or None if the
                 window is closed without pressing a button.
         """
-        sd = MessageDialog(
+        dialog = MessageDialog(
             title=title,
             message=message,
             parent=parent,
@@ -1460,8 +1518,12 @@ class Messagebox:
             localize=True,
             **kwargs,
         )
-        sd.show()
-        return sd.result
+        if "position" in kwargs:
+            position = kwargs.pop("position")
+        else:
+            position = None
+        dialog.show(position)
+        return dialog.result
 
     @staticmethod
     def retrycancel(message, title=" ", alert=False, parent=None, **kwargs):
@@ -1496,7 +1558,7 @@ class Messagebox:
                 The symbolic name of the button pressed, or None if the
                 window is closed without pressing a button.
         """
-        sd = MessageDialog(
+        dialog = MessageDialog(
             title=title,
             message=message,
             parent=parent,
@@ -1505,8 +1567,12 @@ class Messagebox:
             localize=True,
             **kwargs,
         )
-        sd.show()
-        return sd.result
+        if "position" in kwargs:
+            position = kwargs.pop("position")
+        else:
+            position = None
+        dialog.show(position)
+        return dialog.result
 
 
 class Querybox:
@@ -1515,14 +1581,12 @@ class Querybox:
 
     @staticmethod
     def get_color(
-        parent=None,
-        title="Color Chooser",
-        initialcolor=None,
+        parent=None, title="Color Chooser", initialcolor=None, **kwargs
     ):
-        """Show a color picker and return the select color when the 
+        """Show a color picker and return the select color when the
         user pressed OK.
 
-        ![](../../assets/dialogs/querybox-get-color.png)        
+        ![](../../assets/dialogs/querybox-get-color.png)
 
         Parameters:
 
@@ -1533,18 +1597,23 @@ class Querybox:
                 Optional text that appears on the titlebar.
 
             initialcolor (str):
-                The initial color to display in the 'Current' color 
+                The initial color to display in the 'Current' color
                 frame.
 
         Returns:
 
-            Tuple[rgb, hsl, hex]:                
+            Tuple[rgb, hsl, hex]:
                 The selected color in various colors models.
         """
         from ttkbootstrap.dialogs.colorchooser import ColorChooserDialog
-        cd = ColorChooserDialog(parent, title, initialcolor)
-        cd.show()
-        return cd.result
+
+        dialog = ColorChooserDialog(parent, title, initialcolor)
+        if "position" in kwargs:
+            position = kwargs.pop("position")
+        else:
+            position = None
+        dialog.show(position)
+        return dialog.result
 
     @staticmethod
     def get_date(
@@ -1629,10 +1698,14 @@ class Querybox:
                 The string value of the entry widget.
         """
         initialvalue = initialvalue or ""
+        if "position" in kwargs:
+            position = kwargs.pop("position")
+        else:
+            position = None
         dialog = QueryDialog(
             prompt, title, initialvalue, parent=parent, **kwargs
         )
-        dialog.show()
+        dialog.show(position)
         return dialog._result
 
     @staticmethod
@@ -1682,6 +1755,10 @@ class Querybox:
                 The integer value of the entry widget.
         """
         initialvalue = initialvalue or ""
+        if "position" in kwargs:
+            position = kwargs.pop("position")
+        else:
+            position = None
         dialog = QueryDialog(
             prompt,
             title,
@@ -1692,7 +1769,7 @@ class Querybox:
             parent=parent,
             **kwargs,
         )
-        dialog.show()
+        dialog.show(position)
         return dialog._result
 
     @staticmethod
@@ -1742,6 +1819,10 @@ class Querybox:
                 The float value of the entry widget.
         """
         initialvalue = initialvalue or ""
+        if "position" in kwargs:
+            position = kwargs.pop("position")
+        else:
+            position = None
         dialog = QueryDialog(
             prompt,
             title,
@@ -1752,7 +1833,7 @@ class Querybox:
             parent=parent,
             **kwargs,
         )
-        dialog.show()
+        dialog.show(position)
         return dialog._result
 
     @staticmethod
@@ -1775,6 +1856,10 @@ class Querybox:
             Font:
                 A font object.
         """
+        if "position" in kwargs:
+            position = kwargs.pop("position")
+        else:
+            position = None
         dialog = FontDialog(parent=parent, **kwargs)
-        dialog.show()
+        dialog.show(position)
         return dialog.result
